cobbler.modules package
=======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   cobbler.modules.authentication
   cobbler.modules.authorization
   cobbler.modules.installation
   cobbler.modules.managers
   cobbler.modules.serializers

Submodules
----------

cobbler.modules.nsupdate\_add\_system\_post module
--------------------------------------------------

.. automodule:: cobbler.modules.nsupdate_add_system_post
   :members:
   :undoc-members:
   :show-inheritance:

cobbler.modules.nsupdate\_delete\_system\_pre module
----------------------------------------------------

.. automodule:: cobbler.modules.nsupdate_delete_system_pre
   :members:
   :undoc-members:
   :show-inheritance:

cobbler.modules.scm\_track module
---------------------------------

.. automodule:: cobbler.modules.scm_track
   :members:
   :undoc-members:
   :show-inheritance:

cobbler.modules.sync\_post\_restart\_services module
----------------------------------------------------

.. automodule:: cobbler.modules.sync_post_restart_services
   :members:
   :undoc-members:
   :show-inheritance:

cobbler.modules.sync\_post\_wingen module
-----------------------------------------

.. automodule:: cobbler.modules.sync_post_wingen
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: cobbler.modules
   :members:
   :undoc-members:
   :show-inheritance:
